:orphan:

.. _quickstart:

.. currentmodule:: opredflag

Quickstart
==========

This page gives a brief introduction to the library. It assumes you have the library installed.
If you don't, check the :ref:`installing` portion.

The CLI
-------

This package has a CLI which provides much of the main functionality. The help flag contains pretty much all you need to
get started with the CLI:

.. code-block:: shell

    oprf --help
